@@ -7,7 +7,7 @@ lmebreed <-
            model = TRUE, x = TRUE, dateWarning=TRUE, returnParams=FALSE, 
            rotation=FALSE, coefOutRotation=8, ...)
   {
-    my.date <- "2024-10-01" # expiry date
+    my.date <- "2025-01-01" # expiry date
     your.date <- Sys.Date()
     ## if your month is greater than my month you are outdated
     if(dateWarning){
@@ -55,6 +55,7 @@ lmebreed <-
     ## DO TRANSFORMATION BEFORE EVALUATING THE CALL
     '%!in%' <- function(x,y)!('%in%'(x,y)) 
     response <- all.vars(formula)[1]
+    
     if( response %!in% colnames(data) ){stop("Response selected in your formula is not part of the dataset provided.", call. = FALSE)}
     goodRecords <- which(!is.na(data[,response]))
     udu <- list()
@@ -140,7 +141,7 @@ lmebreed <-
         rowsi <- (ind[1]+1L):ind[2]
         pick <- intersect( rownames(Zt), rownames(relfac[[i]])  )
         toAdd <- setdiff( rownames(relfac[[i]]), rownames(Zt) )
-        if(length(pick)==0){stop(paste("The names on your relmat does not coincide with the names in your factor",pnms[i]))}
+        if(length(pick)==0){stop(paste("The names on your relmat does not coincide with the names in your factor",pnms[i],". Maybe you didn't code it as factor."))}
         provRelFac <- relfac[[i]][pick,pick]
         if(nrow(Zt[rowsi,]) == nrow(provRelFac)){ # regular model
           Zt[rowsi,] <- provRelFac %*% Zt[rowsi,]
